@@ -1,21 +1,23 @@
-from autoarray.mask.mask import Mask as mask
-from autoarray.structures.arrays import Array as array
+from autoarray.mask.mask import Mask
+from autoarray.structures.arrays import Array
 from autoarray.structures.grids import (
-    Grid as grid,
-    GridIrregular as grid_irregular,
-    GridRectangular as grid_rectangular,
-    GridVoronoi as grid_voronoi,
-    Coordinates as coordinates,
+    Grid,
+    GridIrregular,
+    GridRectangular,
+    GridVoronoi,
+    Coordinates,
 )
-from autoarray.structures.kernel import Kernel as kernel
-from autoarray.structures.visibilities import Visibilities as visibilities
-from autoarray.structures.arrays import MaskedArray as masked_array
-from autoarray.structures.grids import MaskedGrid as masked_grid
-from autoarray.dataset.imaging import Imaging as imaging
-from autoarray.dataset.interferometer import Interferometer as interferometer
-from autoarray.dataset import data_converter
-from autoarray.operators.convolver import Convolver as convolver
-from autoarray.operators.transformer import Transformer as transformer
+from autoarray.structures.kernel import Kernel
+from autoarray.structures.visibilities import Visibilities
+from autoarray.structures.arrays import MaskedArray
+from autoarray.structures.grids import MaskedGrid
+from autoarray.dataset.imaging import Imaging
+from autoarray.dataset.interferometer import Interferometer
+from autoarray.dataset import preprocess
+from autoarray.operators.convolver import Convolver
+from autoarray.operators.transformer import TransformerDFT
+from autoarray.operators.transformer import TransformerFFT
+from autoarray.operators.transformer import TransformerNUFFT
 from autoarray.operators.inversion.mappers import mapper
 from autoarray.operators.inversion.inversions import inversion
 from autoarray.operators.inversion import pixelizations as pix, regularization as reg
@@ -29,21 +31,21 @@ from autoastro.profiles import (
     light_and_mass_profiles as lmp,
 )
 from autoastro.galaxy.galaxy import Galaxy, HyperGalaxy, Redshift
-from autoastro.galaxy.galaxy_data import GalaxyData as galaxy_data
-from autoastro.galaxy.fit_galaxy import GalaxyFit as fit_galaxy
+from autoastro.galaxy.galaxy_data import GalaxyData
+from autoastro.galaxy.fit_galaxy import FitGalaxy
 from autoastro.galaxy.galaxy_model import GalaxyModel
 from autoastro.hyper import hyper_data
 
-from autolens import simulator
-from autolens.dataset.dataset import (
-    MaskedImaging as masked_imaging,
-    MaskedInterferometer as masked_interferometer,
+from autolens.dataset.imaging import MaskedImaging, SimulatorImaging
+from autolens.dataset.interferometer import (
+    MaskedInterferometer,
+    SimulatorInterferometer,
 )
 from autolens.lens.plane import Plane
 from autolens.lens.ray_tracing import Tracer
 from autolens import util
-from autolens.fit.fit import fit
-from autolens.fit.fit import PositionsFit as fit_positions
+from autolens.fit.fit import FitImaging, FitInterferometer
+from autolens.fit.fit import FitPositions
 from autolens.pipeline import tagging
 from autolens.pipeline.phase.abstract import phase
 from autolens.pipeline.phase.abstract.phase import AbstractPhase
@@ -67,4 +69,4 @@ from autolens.pipeline.pipeline import PipelineDataset, PipelinePositions
 from autolens.pipeline import setup
 from autolens import plot
 
-__version__ = '0.41.0'
+__version__ = '0.42.1'
