@@ -1,6 +1,7 @@
 from astropy import cosmology as cosmo
 
 import autofit as af
+from autoarray.operators import transformer
 from autolens.pipeline import tagging
 from autolens.pipeline.phase import dataset
 from autolens.pipeline.phase.interferometer.analysis import Analysis
@@ -24,9 +25,10 @@ class PhaseInterferometer(dataset.PhaseDataset):
         paths,
         *,
         real_space_mask,
+        transformer_class=transformer.TransformerNUFFT,
         galaxies=None,
         hyper_background_noise=None,
-        optimizer_class=af.MultiNest,
+        non_linear_class=af.MultiNest,
         cosmology=cosmo.Planck15,
         sub_size=2,
         primary_beam_shape_2d=None,
@@ -43,7 +45,7 @@ class PhaseInterferometer(dataset.PhaseDataset):
 
         Parameters
         ----------
-        optimizer_class: class
+        non_linear_class: class
             The class of a non_linear optimizer
         sub_size: int
             The side length of the subgrid
@@ -61,7 +63,7 @@ class PhaseInterferometer(dataset.PhaseDataset):
         super().__init__(
             paths,
             galaxies=galaxies,
-            optimizer_class=optimizer_class,
+            non_linear_class=non_linear_class,
             cosmology=cosmology,
         )
 
@@ -73,6 +75,7 @@ class PhaseInterferometer(dataset.PhaseDataset):
             model=self.model,
             sub_size=sub_size,
             real_space_mask=real_space_mask,
+            transformer_class=transformer_class,
             primary_beam_shape_2d=primary_beam_shape_2d,
             positions_threshold=positions_threshold,
             pixel_scale_interpolation_grid=pixel_scale_interpolation_grid,
