@@ -5,11 +5,13 @@ import pytest
 import shutil
 
 import autolens as al
-from autolens.simulator import simulator
 
 
 def test__simulate_imaging_data_and_fit__no_psf_blurring__chi_squared_is_0__noise_normalization_correct():
-    psf = al.kernel.manual_2d(
+
+    grid = al.Grid.uniform(shape_2d=(11, 11), pixel_scales=0.2, sub_size=2)
+
+    psf = al.Kernel.manual_2d(
         array=np.array([[0.0, 0.0, 0.0], [0.0, 1.0, 0.0], [0.0, 0.0, 0.0]]),
         pixel_scales=0.2,
     )
@@ -27,21 +29,16 @@ def test__simulate_imaging_data_and_fit__no_psf_blurring__chi_squared_is_0__nois
 
     tracer = al.Tracer.from_galaxies(galaxies=[lens_galaxy, source_galaxy])
 
-    imaging_simulator = simulator.ImagingSimulator(
-        shape_2d=(11, 11),
-        pixel_scales=0.2,
-        sub_size=2,
-        exposure_time=300.0,
+    simulator = al.SimulatorImaging(
+        exposure_time_map=al.Array.full(fill_value=300.0, shape_2d=grid.shape_2d),
         psf=psf,
-        background_level=0.0,
+        background_sky_map=al.Array.zeros(shape_2d=grid.shape_2d),
         add_noise=False,
     )
 
-    imaging_simulated = imaging_simulator.from_tracer(tracer=tracer)
+    imaging = simulator.from_tracer_and_grid(tracer=tracer, grid=grid)
 
-    imaging_simulated.noise_map = al.array.ones(
-        shape_2d=imaging_simulated.image.shape_2d
-    )
+    imaging.noise_map = al.Array.ones(shape_2d=imaging.image.shape_2d)
 
     path = "{}/data_temp/simulate_and_fit".format(
         os.path.dirname(os.path.realpath(__file__))
@@ -55,28 +52,28 @@ def test__simulate_imaging_data_and_fit__no_psf_blurring__chi_squared_is_0__nois
     if os.path.exists(path) is False:
         os.makedirs(path)
 
-    imaging_simulated.output_to_fits(
+    imaging.output_to_fits(
         image_path=path + "/image.fits",
         noise_map_path=path + "/noise_map.fits",
         psf_path=path + "/psf.fits",
     )
 
-    imaging = al.imaging.from_fits(
+    imaging = al.Imaging.from_fits(
         image_path=path + "/image.fits",
         noise_map_path=path + "/noise_map.fits",
         psf_path=path + "/psf.fits",
         pixel_scales=0.2,
     )
 
-    mask = al.mask.circular(
+    mask = al.Mask.circular(
         shape_2d=imaging.image.shape_2d, pixel_scales=0.2, sub_size=2, radius=0.8
     )
 
-    masked_imaging = al.masked_imaging(imaging=imaging, mask=mask)
+    masked_imaging = al.MaskedImaging(imaging=imaging, mask=mask)
 
     tracer = al.Tracer.from_galaxies(galaxies=[lens_galaxy, source_galaxy])
 
-    fit = al.fit(masked_dataset=masked_imaging, tracer=tracer)
+    fit = al.FitImaging(masked_imaging=masked_imaging, tracer=tracer)
 
     assert fit.chi_squared == 0.0
 
@@ -90,9 +87,11 @@ def test__simulate_imaging_data_and_fit__no_psf_blurring__chi_squared_is_0__nois
 
 def test__simulate_imaging_data_and_fit__include_psf_blurring__chi_squared_is_0__noise_normalization_correct():
 
-    psf = al.kernel.from_gaussian(shape_2d=(3, 3), pixel_scales=0.2, sigma=0.75)
+    grid = al.Grid.uniform(shape_2d=(11, 11), pixel_scales=0.2, sub_size=1)
 
-    grid = al.grid.uniform(shape_2d=(11, 11), pixel_scales=0.2, sub_size=1)
+    psf = al.Kernel.from_gaussian(
+        shape_2d=(3, 3), pixel_scales=0.2, sigma=0.75, renormalize=True
+    )
 
     lens_galaxy = al.Galaxy(
         redshift=0.5,
@@ -105,24 +104,15 @@ def test__simulate_imaging_data_and_fit__include_psf_blurring__chi_squared_is_0_
     )
     tracer = al.Tracer.from_galaxies(galaxies=[lens_galaxy, source_galaxy])
 
-    imaging_simulator = simulator.ImagingSimulator(
-        shape_2d=(11, 11),
-        pixel_scales=0.2,
-        sub_size=1,
-        exposure_time=300.0,
+    simulator = al.SimulatorImaging(
+        exposure_time_map=al.Array.full(fill_value=300.0, shape_2d=grid.shape_2d),
         psf=psf,
-        background_level=0.0,
+        background_sky_map=al.Array.zeros(shape_2d=grid.shape_2d),
         add_noise=False,
     )
 
-    imaging_simulated = imaging_simulator.from_image(
-        image=tracer.padded_profile_image_from_grid_and_psf_shape(
-            grid=grid, psf_shape_2d=psf.shape_2d
-        )
-    )
-    imaging_simulated.noise_map = al.array.ones(
-        shape_2d=imaging_simulated.image.shape_2d
-    )
+    imaging = simulator.from_tracer_and_grid(tracer=tracer, grid=grid)
+    imaging.noise_map = al.Array.ones(shape_2d=imaging.image.shape_2d)
 
     path = "{}/data_temp/simulate_and_fit".format(
         os.path.dirname(os.path.realpath(__file__))
@@ -136,28 +126,28 @@ def test__simulate_imaging_data_and_fit__include_psf_blurring__chi_squared_is_0_
     if os.path.exists(path) is False:
         os.makedirs(path)
 
-    imaging_simulated.output_to_fits(
+    imaging.output_to_fits(
         image_path=path + "/image.fits",
         noise_map_path=path + "/noise_map.fits",
         psf_path=path + "/psf.fits",
     )
 
-    imaging = al.imaging.from_fits(
+    simulator = al.Imaging.from_fits(
         image_path=path + "/image.fits",
         noise_map_path=path + "/noise_map.fits",
         psf_path=path + "/psf.fits",
         pixel_scales=0.2,
     )
 
-    mask = al.mask.circular(
-        shape_2d=imaging.image.shape_2d, pixel_scales=0.2, sub_size=1, radius=0.8
+    mask = al.Mask.circular(
+        shape_2d=simulator.image.shape_2d, pixel_scales=0.2, sub_size=1, radius=0.8
     )
 
-    masked_imaging = al.masked_imaging(imaging=imaging, mask=mask)
+    masked_imaging = al.MaskedImaging(imaging=simulator, mask=mask)
 
     tracer = al.Tracer.from_galaxies(galaxies=[lens_galaxy, source_galaxy])
 
-    fit = al.fit(masked_dataset=masked_imaging, tracer=tracer)
+    fit = al.FitImaging(masked_imaging=masked_imaging, tracer=tracer)
 
     assert fit.chi_squared == pytest.approx(0.0, 1e-4)
 
@@ -171,6 +161,8 @@ def test__simulate_imaging_data_and_fit__include_psf_blurring__chi_squared_is_0_
 
 def test__simulate_interferometer_data_and_fit__chi_squared_is_0__noise_normalization_correct():
 
+    grid = al.Grid.uniform(shape_2d=(51, 51), pixel_scales=0.1, sub_size=2)
+
     lens_galaxy = al.Galaxy(
         redshift=0.5,
         light=al.lp.EllipticalSersic(centre=(0.1, 0.1), intensity=0.1),
@@ -184,18 +176,16 @@ def test__simulate_interferometer_data_and_fit__chi_squared_is_0__noise_normaliz
 
     tracer = al.Tracer.from_galaxies(galaxies=[lens_galaxy, source_galaxy])
 
-    interferometer_simulator = simulator.InterferometerSimulator(
-        real_space_shape_2d=(51, 51),
-        real_space_pixel_scales=0.1,
+    simulator = al.SimulatorInterferometer(
         uv_wavelengths=np.ones(shape=(7, 2)),
-        sub_size=2,
-        exposure_time=300.0,
-        background_level=0.0,
+        transformer_class=al.TransformerDFT,
+        exposure_time_map=al.Array.full(fill_value=300.0, shape_2d=grid.shape_2d),
+        background_sky_map=al.Array.zeros(shape_2d=grid.shape_2d),
         noise_if_add_noise_false=1.0,
         noise_sigma=None,
     )
 
-    interferometer_simulated = interferometer_simulator.from_tracer(tracer=tracer)
+    interferometer = simulator.from_tracer_and_grid(tracer=tracer, grid=grid)
 
     path = "{}/data_temp/simulate_and_fit".format(
         os.path.dirname(os.path.realpath(__file__))
@@ -209,13 +199,13 @@ def test__simulate_interferometer_data_and_fit__chi_squared_is_0__noise_normaliz
     if os.path.exists(path) is False:
         os.makedirs(path)
 
-    interferometer_simulated.output_to_fits(
+    interferometer.output_to_fits(
         visibilities_path=path + "/visibilities.fits",
         noise_map_path=path + "/noise_map.fits",
         uv_wavelengths_path=path + "/uv_wavelengths.fits",
     )
 
-    interferometer = al.interferometer.from_fits(
+    interferometer = al.Interferometer.from_fits(
         visibilities_path=path + "/visibilities.fits",
         noise_map_path=path + "/noise_map.fits",
         uv_wavelengths_path=path + "/uv_wavelengths.fits",
@@ -223,18 +213,21 @@ def test__simulate_interferometer_data_and_fit__chi_squared_is_0__noise_normaliz
 
     visibilities_mask = np.full(fill_value=False, shape=(7, 2))
 
-    real_space_mask = al.mask.unmasked(shape_2d=(51, 51), pixel_scales=0.1, sub_size=2)
+    real_space_mask = al.Mask.unmasked(shape_2d=(51, 51), pixel_scales=0.1, sub_size=2)
 
-    masked_interferometer = al.masked_interferometer(
+    masked_interferometer = al.MaskedInterferometer(
         interferometer=interferometer,
         visibilities_mask=visibilities_mask,
         real_space_mask=real_space_mask,
+        transformer_class=al.TransformerDFT,
         inversion_uses_border=False,
     )
 
     tracer = al.Tracer.from_galaxies(galaxies=[lens_galaxy, source_galaxy])
 
-    fit = al.fit(masked_dataset=masked_interferometer, tracer=tracer)
+    fit = al.FitInterferometer(
+        masked_interferometer=masked_interferometer, tracer=tracer
+    )
 
     assert fit.chi_squared == 0.0
 
@@ -252,7 +245,9 @@ def test__simulate_interferometer_data_and_fit__chi_squared_is_0__noise_normaliz
 
     tracer = al.Tracer.from_galaxies(galaxies=[lens_galaxy, source_galaxy])
 
-    fit = al.fit(masked_dataset=masked_interferometer, tracer=tracer)
+    fit = al.FitInterferometer(
+        masked_interferometer=masked_interferometer, tracer=tracer
+    )
     assert abs(fit.chi_squared) < 1.0e-4
 
     path = "{}/data_temp".format(
