@@ -5,10 +5,10 @@ import time
 
 repeats = 1
 
-total_visibilities = 10000
+total_visibilities = 100000
 pixelization_shape_2d = (30, 30)
 
-real_space_shape_2d = (100, 100)
+real_space_shape_2d = (256, 256)
 real_space_pixel_scales = 0.05
 real_space_sub_size = 1
 real_space_radius = 3.0
@@ -31,11 +31,13 @@ print()
 # Only delete this if the memory use looks... Okay
 # stop
 
-visibilities = al.visibilities.ones(shape_1d=(total_visibilities,))
-uv_wavelengths = np.ones(shape=(total_visibilities, 2))
-noise_map = al.visibilities.ones(shape_1d=(total_visibilities,))
+vis = np.random.uniform(low=-5.0, high=5.0, size=(total_visibilities, 2))
 
-interferometer = al.interferometer(
+visibilities = al.Visibilities.manual_1d(visibilities=vis)
+uv_wavelengths = np.ones(shape=(total_visibilities, 2))
+noise_map = al.Visibilities.ones(shape_1d=(total_visibilities,))
+
+interferometer = al.Interferometer(
     visibilities=visibilities, noise_map=noise_map, uv_wavelengths=uv_wavelengths
 )
 
@@ -58,15 +60,18 @@ source_galaxy = al.Galaxy(
     regularization=al.reg.Constant(coefficient=1.0),
 )
 
-mask = al.mask.circular(
+mask = al.Mask.circular(
     shape_2d=real_space_shape_2d,
     pixel_scales=real_space_pixel_scales,
     sub_size=real_space_sub_size,
     radius=real_space_radius,
 )
 
-masked_interferometer = al.masked_interferometer(
-    interferometer=interferometer, real_space_mask=mask
+masked_interferometer = al.MaskedInterferometer(
+    interferometer=interferometer,
+    real_space_mask=mask,
+    visibilities_mask=np.full(fill_value=False, shape=visibilities.shape),
+    transformer_class=al.TransformerNUFFT,
 )
 
 print("Number of points = " + str(masked_interferometer.grid.sub_shape_1d) + "\n")
@@ -112,6 +117,7 @@ diff = time.time() - start
 print("Time to compute mapping matrix = {}".format(diff / repeats))
 
 start = time.time()
+
 for i in range(repeats):
     transformed_mapping_matrices = masked_interferometer.transformer.transformed_mapping_matrices_from_mapping_matrix(
         mapping_matrix=mapping_matrix
